==> bgp-bmp-api-0.13.2-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/route/monitoring/message/UpdateBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.route.monitoring.message;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.path.attributes.Attributes;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.update.message.Nlri;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.update.message.WithdrawnRoutes;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link UpdateBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     UpdateBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new UpdateBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of UpdateBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see UpdateBuilder
 * @see Builder
 *
 */
public class UpdateBuilder implements Builder<Update> {

    private Attributes _attributes;
    private List<Nlri> _nlri;
    private List<WithdrawnRoutes> _withdrawnRoutes;


    Map<Class<? extends Augmentation<Update>>, Augmentation<Update>> augmentation = Collections.emptyMap();

    public UpdateBuilder() {
    }
    public UpdateBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage arg) {
        this._withdrawnRoutes = arg.getWithdrawnRoutes();
        this._nlri = arg.getNlri();
        this._attributes = arg.getAttributes();
    }
    public UpdateBuilder(org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes arg) {
        this._attributes = arg.getAttributes();
    }

    public UpdateBuilder(Update base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<Update>>, Augmentation<Update>> aug =((AugmentationHolder<Update>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._attributes = base.getAttributes();
        this._nlri = base.getNlri();
        this._withdrawnRoutes = base.getWithdrawnRoutes();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage</li>
     * <li>org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage) {
            this._withdrawnRoutes = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage)arg).getWithdrawnRoutes();
            this._nlri = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage)arg).getNlri();
            isValidArg = true;
        }
        if (arg instanceof org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes) {
            this._attributes = ((org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes)arg).getAttributes();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage, org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes]");
    }

    public Attributes getAttributes() {
        return _attributes;
    }
    
    public List<Nlri> getNlri() {
        return _nlri;
    }
    
    public List<WithdrawnRoutes> getWithdrawnRoutes() {
        return _withdrawnRoutes;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Update>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public UpdateBuilder setAttributes(final Attributes value) {
        this._attributes = value;
        return this;
    }
    public UpdateBuilder setNlri(final List<Nlri> values) {
        this._nlri = values;
        return this;
    }
    
    public UpdateBuilder setWithdrawnRoutes(final List<WithdrawnRoutes> values) {
        this._withdrawnRoutes = values;
        return this;
    }
    
    
    public UpdateBuilder addAugmentation(Class<? extends Augmentation<Update>> augmentationType, Augmentation<Update> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public UpdateBuilder removeAugmentation(Class<? extends Augmentation<Update>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Update build() {
        return new UpdateImpl(this);
    }

    private static final class UpdateImpl
        extends AbstractAugmentable<Update>
        implements Update {
    
        private final Attributes _attributes;
        private final List<Nlri> _nlri;
        private final List<WithdrawnRoutes> _withdrawnRoutes;
    
        UpdateImpl(UpdateBuilder base) {
            super(base.augmentation);
            this._attributes = base.getAttributes();
            this._nlri = base.getNlri();
            this._withdrawnRoutes = base.getWithdrawnRoutes();
        }
    
        @Override
        public Attributes getAttributes() {
            return _attributes;
        }
        
        @Override
        public List<Nlri> getNlri() {
            return _nlri;
        }
        
        @Override
        public List<WithdrawnRoutes> getWithdrawnRoutes() {
            return _withdrawnRoutes;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_attributes);
            result = prime * result + Objects.hashCode(_nlri);
            result = prime * result + Objects.hashCode(_withdrawnRoutes);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!Update.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            Update other = (Update)obj;
            if (!Objects.equals(_attributes, other.getAttributes())) {
                return false;
            }
            if (!Objects.equals(_nlri, other.getNlri())) {
                return false;
            }
            if (!Objects.equals(_withdrawnRoutes, other.getWithdrawnRoutes())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                UpdateImpl otherImpl = (UpdateImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<Update>>, Augmentation<Update>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("Update");
            CodeHelpers.appendValue(helper, "_attributes", _attributes);
            CodeHelpers.appendValue(helper, "_nlri", _nlri);
            CodeHelpers.appendValue(helper, "_withdrawnRoutes", _withdrawnRoutes);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}

==> bgp-bmp-api-0.16.0-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/bmp/message/rev200120/route/monitoring/message/UpdateBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bmp.message.rev200120.route.monitoring.message;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Objects;
import javax.annotation.processing.Generated;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.PathAttributes;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.UpdateMessage;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.path.attributes.Attributes;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.update.message.Nlri;
import org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.bgp.message.rev200120.update.message.WithdrawnRoutes;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link UpdateBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     UpdateBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new UpdateBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of UpdateBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see UpdateBuilder
 * @see Builder
 *
 */
@Generated("mdsal-binding-generator")
public class UpdateBuilder implements Builder<Update> {

    private Attributes _attributes;
    private List<Nlri> _nlri;
    private List<WithdrawnRoutes> _withdrawnRoutes;


    Map<Class<? extends Augmentation<Update>>, Augmentation<Update>> augmentation = Collections.emptyMap();

    public UpdateBuilder() {
    }
    
    
    
    public UpdateBuilder(UpdateMessage arg) {
        this._withdrawnRoutes = arg.getWithdrawnRoutes();
        this._nlri = arg.getNlri();
        this._attributes = arg.getAttributes();
    }
    public UpdateBuilder(PathAttributes arg) {
        this._attributes = arg.getAttributes();
    }

    public UpdateBuilder(Update base) {
        Map<Class<? extends Augmentation<Update>>, Augmentation<Update>> aug = base.augmentations();
        if (!aug.isEmpty()) {
            this.augmentation = new HashMap<>(aug);
        }
        this._attributes = base.getAttributes();
        this._nlri = base.getNlri();
        this._withdrawnRoutes = base.getWithdrawnRoutes();
    }

    /**
     * Set fields from given grouping argument. Valid argument is instance of one of following types:
     * <ul>
     * <li>UpdateMessage</li>
     * <li>PathAttributes</li>
     * </ul>
     *
     * @param arg grouping object
     * @throws IllegalArgumentException if given argument is none of valid types or has property with incompatible value
    */
    public void fieldsFrom(DataObject arg) {
        boolean isValidArg = false;
        if (arg instanceof UpdateMessage) {
            this._withdrawnRoutes = ((UpdateMessage)arg).getWithdrawnRoutes();
            this._nlri = ((UpdateMessage)arg).getNlri();
            isValidArg = true;
        }
        if (arg instanceof PathAttributes) {
            this._attributes = ((PathAttributes)arg).getAttributes();
            isValidArg = true;
        }
        CodeHelpers.validValue(isValidArg, arg, "[UpdateMessage, PathAttributes]");
    }

    public Attributes getAttributes() {
        return _attributes;
    }
    
    public List<Nlri> getNlri() {
        return _nlri;
    }
    
    public List<WithdrawnRoutes> getWithdrawnRoutes() {
        return _withdrawnRoutes;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<Update>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(Objects.requireNonNull(augmentationType));
    }

    
    public UpdateBuilder setAttributes(final Attributes value) {
        this._attributes = value;
        return this;
    }
    public UpdateBuilder setNlri(final List<Nlri> values) {
        this._nlri = values;
        return this;
    }
    
    public UpdateBuilder setWithdrawnRoutes(final List<WithdrawnRoutes> values) {
        this._withdrawnRoutes = values;
        return this;
    }
    
    
    /**
      * Add an augmentation to this builder's product.
      *
      * @param augmentation augmentation to be added
      * @return this builder
      * @throws NullPointerException if {@code augmentation} is null
      */
    public UpdateBuilder addAugmentation(Augmentation<Update> augmentation) {
        Class<? extends Augmentation<Update>> augmentationType = augmentation.implementedInterface();
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentation);
        return this;
    }
    
    /**
      * Remove an augmentation from this builder's product. If this builder does not track such an augmentation
      * type, this method does nothing.
      *
      * @param augmentationType augmentation type to be removed
      * @return this builder
      */
    public UpdateBuilder removeAugmentation(Class<? extends Augmentation<Update>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public Update build() {
        return new UpdateImpl(this);
    }

    private static final class UpdateImpl
        extends AbstractAugmentable<Update>
        implements Update {
    
        private final Attributes _attributes;
        private final List<Nlri> _nlri;
        private final List<WithdrawnRoutes> _withdrawnRoutes;
    
        UpdateImpl(UpdateBuilder base) {
            super(base.augmentation);
            this._attributes = base.getAttributes();
            this._nlri = CodeHelpers.emptyToNull(base.getNlri());
            this._withdrawnRoutes = CodeHelpers.emptyToNull(base.getWithdrawnRoutes());
        }
    
        @Override
        public Attributes getAttributes() {
            return _attributes;
        }
        
        @Override
        public List<Nlri> getNlri() {
            return _nlri;
        }
        
        @Override
        public List<WithdrawnRoutes> getWithdrawnRoutes() {
            return _withdrawnRoutes;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int result = Update.bindingHashCode(this);
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            return Update.bindingEquals(this, obj);
        }
    
        @Override
        public String toString() {
            return Update.bindingToString(this);
        }
    }
}
